@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GHex; see the file COPYING.
-   If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   If not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Author: Jaka Mocnik <jaka@gnu.org>
 */
@@ -26,6 +26,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "findreplace.h"
 #include "ui.h"
@@ -84,8 +85,6 @@ static GtkWidget *create_hex_view(HexDocument *doc)
 
 FindDialog *create_find_dialog()
 {
-	gint i;
-	GSList *group;
 	FindDialog *dialog;
 	GtkWidget *frame;
 
@@ -101,7 +100,7 @@ FindDialog *create_find_dialog()
 	dialog->f_gh = create_hex_view(dialog->f_doc);
 	frame = gtk_frame_new(_("Find String"));
 	gtk_container_add(GTK_CONTAINER(frame), dialog->f_gh);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), frame,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), frame,
 					   TRUE, TRUE, 0);
 	gtk_widget_show(frame);
 	gtk_widget_show(dialog->f_gh);
@@ -109,31 +108,31 @@ FindDialog *create_find_dialog()
 	dialog->f_next = create_button(dialog->window, GTK_STOCK_GO_FORWARD, _("Find _Next"));
 	g_signal_connect (G_OBJECT (dialog->f_next), "clicked",
 					  G_CALLBACK(find_next_cb), dialog);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->f_next,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->f_next,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->f_next, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_next, TRUE);
 	gtk_widget_show(dialog->f_next);
 	dialog->f_prev = create_button(dialog->window, GTK_STOCK_GO_BACK, _("Find _Previous"));
 	g_signal_connect (G_OBJECT (dialog->f_prev), "clicked",
 					  G_CALLBACK(find_prev_cb), dialog);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->f_prev,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->f_prev,
 					   TRUE, TRUE, 0);
 
-	GTK_WIDGET_SET_FLAGS(dialog->f_prev, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_prev, TRUE);
 	gtk_widget_show(dialog->f_prev);
 
 	dialog->f_close = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 	g_signal_connect (G_OBJECT (dialog->f_close),
 					  "clicked", G_CALLBACK(find_cancel_cb),
 					  dialog);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->f_close,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->f_close,
 					   TRUE, TRUE, 0);
 
-	GTK_WIDGET_SET_FLAGS(dialog->f_close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_close, TRUE);
 	gtk_widget_show(dialog->f_close);
 
-	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog->window)->vbox), 2);
-	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
+	gtk_box_set_spacing(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
 
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (dialog->f_gh))) {
 		add_atk_namedesc (dialog->f_gh, _("Find Data"), _("Enter the hex data or ASCII data to search for"));
@@ -145,7 +144,7 @@ FindDialog *create_find_dialog()
 	return dialog;
 }
 
-AdvancedFind_AddDialog *create_advanced_find_add_dialog(AdvancedFindDialog *parent)
+static AdvancedFind_AddDialog *create_advanced_find_add_dialog(AdvancedFindDialog *parent)
 {
 	AdvancedFind_AddDialog *dialog = g_new0(AdvancedFind_AddDialog, 1);
 	GtkWidget *button, *frame, *sep;
@@ -161,38 +160,38 @@ AdvancedFind_AddDialog *create_advanced_find_add_dialog(AdvancedFindDialog *pare
 	dialog->f_gh = create_hex_view(dialog->f_doc);
 	frame = gtk_frame_new(_("Find String"));
 	gtk_container_add(GTK_CONTAINER(frame), dialog->f_gh);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), frame,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), frame,
 					   TRUE, TRUE, 0);
 	gtk_widget_show(frame);
 	gtk_widget_show(dialog->f_gh);
 
-	sep = gtk_hseparator_new();
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), sep,
+	sep = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), sep,
 					   FALSE, FALSE, 0);
 
 	dialog->colour = gtk_color_selection_new();
 	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(dialog->colour),
 												FALSE);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox),
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))),
 					   dialog->colour, FALSE, FALSE, 0);
 	gtk_widget_show(dialog->colour);
 
 	button = create_button(dialog->window, GTK_STOCK_ADD, _("Add"));
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), button,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), button,
 					   TRUE, TRUE, 0);
 	g_signal_connect (G_OBJECT (button),
 					  "clicked", G_CALLBACK(advanced_find_add_add_cb),
 					  dialog);
-	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
 	button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
 	g_signal_connect (G_OBJECT (button),
 					  "clicked", G_CALLBACK(cancel_cb),
 					  dialog->window);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), button,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), button,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(button, TRUE);
 	gtk_widget_show(button);
 
 	return dialog;
@@ -221,9 +220,9 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 
 	create_dialog_title(dialog->window, _("GHex (%s): Find Data"));
 
-	dialog->hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox),
-					   dialog->hbox, TRUE, TRUE, GNOME_PAD_SMALL);
+	dialog->hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))),
+					   dialog->hbox, TRUE, TRUE, 4);
 	gtk_widget_show(dialog->hbox);
 
 	dialog->list = gtk_list_store_new(3,
@@ -248,12 +247,12 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->tree), column);
 
 	gtk_box_pack_start(GTK_BOX(dialog->hbox), dialog->tree,
-					   TRUE, TRUE, GNOME_PAD_SMALL);
+					   TRUE, TRUE, 4);
 	gtk_widget_show (dialog->tree);
 
-	dialog->vbox = gtk_vbox_new(FALSE, 0);
+	dialog->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(dialog->hbox), dialog->vbox,
-					   FALSE, FALSE, GNOME_PAD_SMALL);
+					   FALSE, FALSE, 4);
 	gtk_widget_show(dialog->vbox);
 
 	dialog->f_next = create_button(dialog->window, GTK_STOCK_GO_FORWARD, _("Find _Next"));
@@ -262,7 +261,7 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 	g_signal_connect (G_OBJECT (dialog->f_next),
 					  "clicked", G_CALLBACK(advanced_find_next_cb),
 					  dialog);
-	GTK_WIDGET_SET_FLAGS(dialog->f_next, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_next, TRUE);
 	gtk_widget_show(dialog->f_next);
 
 	dialog->f_prev = create_button(dialog->window, GTK_STOCK_GO_BACK, _("Find _Previous"));
@@ -271,11 +270,11 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 	g_signal_connect (G_OBJECT (dialog->f_prev),
 					  "clicked", G_CALLBACK(advanced_find_prev_cb),
 					  dialog);
-	GTK_WIDGET_SET_FLAGS(dialog->f_prev, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_prev, TRUE);
 	gtk_widget_show(dialog->f_prev);
 
-	sep = gtk_hseparator_new();
-	gtk_box_pack_start(GTK_BOX(dialog->vbox), sep, FALSE, FALSE, GNOME_PAD_SMALL);
+	sep = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+	gtk_box_pack_start(GTK_BOX(dialog->vbox), sep, FALSE, FALSE, 4);
 	gtk_widget_show(sep);
 
 	dialog->f_new = create_button(dialog->window, GTK_STOCK_ADD, _("_Add New"));
@@ -284,7 +283,7 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 	g_signal_connect (G_OBJECT (dialog->f_new),
 					  "clicked", G_CALLBACK(advanced_find_add_cb),
 					  dialog);
-	GTK_WIDGET_SET_FLAGS(dialog->f_new, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_new, TRUE);
 	gtk_widget_show(dialog->f_new);
 
 	dialog->f_remove = create_button(dialog->window, GTK_STOCK_REMOVE, _("_Remove Selected"));
@@ -293,16 +292,16 @@ AdvancedFindDialog *create_advanced_find_dialog(GHexWindow *parent)
 	g_signal_connect (G_OBJECT (dialog->f_remove),
 					  "clicked", G_CALLBACK(advanced_find_delete_cb),
 					  dialog);
-	GTK_WIDGET_SET_FLAGS(dialog->f_remove, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_remove, TRUE);
 	gtk_widget_show(dialog->f_remove);
 
 	dialog->f_close = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
 	g_signal_connect(G_OBJECT(dialog->f_close),
 					 "clicked", G_CALLBACK(advanced_find_close_cb),
 					 dialog);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area),
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))),
 					   dialog->f_close, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->f_close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->f_close, TRUE);
 	gtk_widget_show(dialog->f_close);
 
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (dialog->f_close)))
@@ -319,8 +318,10 @@ static void delete_advanced_find_add_dialog(AdvancedFind_AddDialog *dialog)
 	g_free(dialog);
 }
 
-gboolean advanced_find_foreachfunc_cb(GtkTreeModel *model, GtkTreePath *path,
-									  GtkTreeIter *iter, gpointer data)
+static gboolean advanced_find_foreachfunc_cb (GtkTreeModel *model,
+                                              GtkTreePath  *path,
+                                              GtkTreeIter  *iter,
+                                              gpointer      data)
 {
 	AdvancedFind_ListData *udata;
 	GtkHex *gh = (GtkHex *)data;
@@ -357,7 +358,7 @@ ReplaceDialog *create_replace_dialog()
 	dialog->f_gh = create_hex_view(dialog->f_doc);
 	frame = gtk_frame_new(_("Find String"));
 	gtk_container_add(GTK_CONTAINER(frame), dialog->f_gh);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), frame,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), frame,
 					   TRUE, TRUE, 0);
 	gtk_widget_show(frame);
 	gtk_widget_show(dialog->f_gh);
@@ -366,7 +367,7 @@ ReplaceDialog *create_replace_dialog()
 	dialog->r_gh = create_hex_view(dialog->r_doc);
 	frame = gtk_frame_new(_("Replace With"));
 	gtk_container_add(GTK_CONTAINER(frame), dialog->r_gh);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), frame,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), frame,
 					   TRUE, TRUE, 0);
 	gtk_widget_show(frame);
 	gtk_widget_show(dialog->r_gh);
@@ -375,38 +376,38 @@ ReplaceDialog *create_replace_dialog()
 	g_signal_connect (G_OBJECT (dialog->next),
 					  "clicked", G_CALLBACK(replace_next_cb),
 					  NULL);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->next,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->next,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->next, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->next, TRUE);
 	gtk_widget_show(dialog->next);
 	dialog->replace = gtk_button_new_with_mnemonic(_("_Replace"));
 	g_signal_connect (G_OBJECT (dialog->replace),
 					  "clicked", G_CALLBACK(replace_one_cb),
 					  NULL);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->replace,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->replace,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->replace, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->replace, TRUE);
 	gtk_widget_show(dialog->replace);
 	dialog->replace_all= gtk_button_new_with_mnemonic(_("Replace _All"));
 	g_signal_connect (G_OBJECT (dialog->replace_all),
 					  "clicked", G_CALLBACK(replace_all_cb),
 					  NULL);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->replace_all,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->replace_all,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->replace_all, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->replace_all, TRUE);
 	gtk_widget_show(dialog->replace_all);
 
 	dialog->close = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 	g_signal_connect (G_OBJECT (dialog->close),
 					  "clicked", G_CALLBACK(cancel_cb),
 					  dialog->window);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->close,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->close,
 					   TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS(dialog->close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->close, TRUE);
 	gtk_widget_show(dialog->close);
 	
-	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog->window)->vbox), 2);
-	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
+	gtk_box_set_spacing(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
 
 	if (GTK_IS_ACCESSIBLE(gtk_widget_get_accessible(dialog->f_gh))) {
 		add_atk_namedesc (dialog->f_gh, _("Find Data"), _("Enter the hex data or ASCII data to search for"));
@@ -433,31 +434,34 @@ JumpDialog *create_jump_dialog()
 	create_dialog_title(dialog->window, _("GHex (%s): Jump To Byte"));
 	
 	dialog->int_entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->int_entry,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), dialog->int_entry,
 					   TRUE, TRUE, 0);
+	g_signal_connect_swapped (G_OBJECT (dialog->int_entry),
+	                          "activate", G_CALLBACK(gtk_window_activate_default),
+	                          GTK_WINDOW (dialog->window));
 	gtk_widget_show(dialog->int_entry);
 
 	dialog->ok = gtk_button_new_from_stock (GTK_STOCK_OK);
 	g_signal_connect (G_OBJECT (dialog->ok),
 					  "clicked", G_CALLBACK(goto_byte_cb),
 					  dialog->int_entry);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->ok,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->ok,
 					   TRUE, TRUE, 0);
 
-	GTK_WIDGET_SET_FLAGS(dialog->ok, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->ok, TRUE);
 	gtk_widget_show(dialog->ok);
 	dialog->cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 	g_signal_connect (G_OBJECT (dialog->cancel),
 					  "clicked", G_CALLBACK(cancel_cb),
 					  dialog->window);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->action_area), dialog->cancel,
+	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog->window))), dialog->cancel,
 					   TRUE, TRUE, 0);
 
-	GTK_WIDGET_SET_FLAGS(dialog->cancel, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(dialog->cancel, TRUE);
 	gtk_widget_show(dialog->cancel);
 	
-	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog->window)->vbox), 2);
-	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
+	gtk_box_set_spacing(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog->window))), 2);
 
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(dialog->int_entry))) {
 		add_atk_namedesc (dialog->int_entry, _("Jump to byte"), _("Enter the byte to jump to"));
@@ -587,6 +591,7 @@ static void find_prev_cb(GtkButton *button, FindDialog *dialog)
 static void goto_byte_cb(GtkButton *button, GtkWidget *w)
 {
 	guint byte = 2, len, i;
+	gint is_relative = 0;
 	gboolean is_hex;
 	const gchar *byte_str = gtk_entry_get_text(GTK_ENTRY(jump_dialog->int_entry));
 	GHexWindow *win = ghex_window_get_active();
@@ -597,8 +602,20 @@ static void goto_byte_cb(GtkButton *button, GtkWidget *w)
 								"cursor in!"));
 		return;
 	}
-
-	if((len = strlen(byte_str)) == 0) {
+	
+	len = strlen(byte_str);
+	
+	if(len > 1 && byte_str[0] == '+') {
+		is_relative = 1;
+		byte_str++;
+		len--;
+	} else if(len > 1 && byte_str[0] == '-') {
+		is_relative = -1;
+		byte_str++;
+		len--;
+	}
+	
+	if(len == 0) {
 		display_error_dialog (win, _("No offset has been specified!"));
 		return;
 	}
@@ -621,6 +638,15 @@ static void goto_byte_cb(GtkButton *button, GtkWidget *w)
 	if((i == len) &&
 	   ((sscanf(byte_str, "0x%x", &byte) == 1) ||
 		(sscanf(byte_str, "%d", &byte) == 1))) {
+		if(is_relative) {
+			if(is_relative == -1 && byte > win->gh->cursor_pos) {
+				display_error_dialog(win,
+								 _("The specified offset is beyond the "
+								" file boundaries!"));
+				return;
+			}
+			byte = byte * is_relative + win->gh->cursor_pos;
+		}
 		if(byte >= win->gh->document->file_size)
 			display_error_dialog(win,
 								 _("Can not position cursor beyond the "
@@ -632,7 +658,8 @@ static void goto_byte_cb(GtkButton *button, GtkWidget *w)
 		display_error_dialog(win,
 							 _("You may only give the offset as:\n"
 							   "  - a positive decimal number, or\n"
-							   "  - a hex number, beginning with '0x'"));
+							   "  - a hex number, beginning with '0x', or\n"
+							   "  - a '+' or '-' sign, followed by a relative offset"));
 }
 
 static void replace_next_cb(GtkButton *button, gpointer unused)
@@ -775,7 +802,7 @@ static void advanced_find_add_add_cb(GtkButton *button,
 static void advanced_find_add_cb(GtkButton *button, AdvancedFindDialog *dialog)
 {
 	gint ret;
-	if(!GTK_WIDGET_VISIBLE(dialog->addDialog->window)) {
+	if(!gtk_widget_get_visible(dialog->addDialog->window)) {
 		gtk_window_set_position (GTK_WINDOW(dialog->addDialog->window), GTK_WIN_POS_MOUSE);
 		gtk_widget_show(dialog->addDialog->window);
 	}
@@ -785,7 +812,7 @@ static void advanced_find_add_cb(GtkButton *button, AdvancedFindDialog *dialog)
 	if (ret != GTK_RESPONSE_NONE)
 	{
 		gchar *colour;
-		GdkColor gcol;
+		GdkRGBA rgba;
 		AdvancedFind_ListData *data = g_new0(AdvancedFind_ListData, 1);
 		GtkHex *gh = dialog->parent->gh;
 		GtkTreeIter iter;
@@ -796,10 +823,9 @@ static void advanced_find_add_cb(GtkButton *button, AdvancedFindDialog *dialog)
 			display_error_dialog (dialog->parent, _("No string to search for!"));
 			return;
 		}
-		gtk_color_selection_get_current_color
-			(GTK_COLOR_SELECTION(dialog->addDialog->colour), &gcol);
-		colour = g_strdup_printf("#%02x%02x%02x",
-								 gcol.red, gcol.green, gcol.blue);
+		gtk_color_selection_get_current_rgba (GTK_COLOR_SELECTION (dialog->addDialog->colour),
+		                                      &rgba);
+		colour = gdk_rgba_to_string (&rgba);
 		data->auto_highlight = gtk_hex_insert_autohighlight(gh, data->str, data->str_len, colour);
 		gtk_list_store_append(dialog->list, &iter);
 		gtk_list_store_set(dialog->list, &iter,
